Evaluates generic constraints from tool signatures against tool call args.
Summary
Functions
@spec check(map(), Cyclium.Intent.ToolSignature.t()) :: :ok | {:deny, binary()}
Evaluates generic constraints from tool signatures against tool call args.
@spec check(map(), Cyclium.Intent.ToolSignature.t()) :: :ok | {:deny, binary()}